@@ -2,6 +2,7 @@
 function(treatment,means,minimum) {
 n<-length(means)
 z<-data.frame(treatment,means)
+letras<-c(letters[1:26],LETTERS[1:26])
 # ordena tratamientos
 w<-z[order(z[,2],decreasing=TRUE),]
 M<-rep("",n)
@@ -12,14 +13,14 @@ i<-1
 cambio<-n
 cambio1<-0
 chequeo=0
-M[1]<-letters[k]
+M[1]<-letras[k]
 while(j<n) {
 chequeo<-chequeo+1
 if (chequeo > n) break
 for(i in j:n) {
 s<-abs(w[i,2]-w[j,2])<=minimum
 if(s) {
-if(lastC(M[i]) != letters[k])M[i]<-paste(M[i],letters[k],sep="")
+if(lastC(M[i]) != letras[k])M[i]<-paste(M[i],letras[k],sep="")
 }
 else {
 k<-k+1
@@ -27,7 +28,7 @@ cambio<-i
 cambio1<-0
 ja<-j
 for(jj in cambio:n) M[jj]<-paste(M[jj]," ",sep="")
-M[cambio]<-paste(M[cambio],letters[k],sep="")
+M[cambio]<-paste(M[cambio],letras[k],sep="")
 for( v in ja:cambio) {
 if(abs(w[v,2]-w[cambio,2])>minimum) {j<-j+1
 cambio1<-1
