@@ -24,7 +24,8 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL)
     names(means)[1:2]<-c(name.t,name.y)
 #   row.names(means)<-means[,1]
     ntr<-nrow(means)
-    Tprob <- qf(1-alpha,ntr-1, DFerror)
+	Fprob <- qf(1-alpha,ntr-1, DFerror)
+	Tprob <- sqrt(Fprob * (ntr - 1))	
     nr<- 1/mean(1/nn[,2])
     cat("\nStudy:", main)
     cat("\n\nScheffe Test for",name.y,"\n") 
@@ -32,8 +33,8 @@ function (y, trt, DFerror, MSerror, Fc, alpha=0.05, group=TRUE,main = NULL)
     cat(paste(name.t,",",sep="")," means\n\n")
     print(data.frame(row.names = means[,1], means[,-1]))
 cat("\nalpha:",alpha,"; Df Error:",DFerror,"\n")
-cat("Critical Value of F:", Tprob,"\n")
-scheffe <- sqrt(Tprob*(ntr-1)*2*MSerror/nr)
+cat("Critical Value of F:", Fprob,"\n")
+scheffe <- Tprob*sqrt(2*MSerror/nr)
 if (length(unique(nn[,2]))!=1) {
 cat("\nHarmonic Mean of Cell Sizes ", nr )
 }
